@@ -224,7 +224,11 @@ def display_img(fn, *, width = None):
       is_in_colab = True
     except:
       is_in_colab = False
-    if not is_in_colab:
+    is_fn_showable = True
+    if fn.startswith('/'):
+        is_fn_showable = False
+    is_using_html = is_fn_showable and not is_in_colab
+    if is_using_html:
         display(HTML(data = f"<img src='{fn}' {show_width} />"))
     else:
         display(Image(filename = fn, width = width))
@@ -262,7 +266,7 @@ def plot_save(
                 "set xlabel '$x$'",
                 "set ylabel '$y$'",
                 ]
-        displayln_info(0, f"cmds={cmds}")
+        displayln_info(f"cmds={cmds}")
     if dts is None:
         x = np.arange(31) * (6 / 30) - 3
         y = np.cos(x)
